## Polars X Oracle helper tool

list[dict] is lame, dataframes are cool
When SQL queries return dataframes, why shouldn't the drivers do the same?
asyncdb-polars exists with a postgres version.

IMO it is easier to have a different lib per each database because its easier to maintain.